@@ -10,7 +10,7 @@ Created on Oct 10, 2011
 
 from dtrace import DTraceConsumer
 
-SCRIPT = 'dtrace:::BEGIN {trace("Hello World");}'
+SCRIPT = 'dtrace:::BEGIN {trace("Hello World"); exit(0);}'
 
 
 def main():
@@ -18,7 +18,9 @@ def main():
     Run DTrace...
     '''
     consumer = DTraceConsumer()
-    consumer.run_script(SCRIPT)
+    # Even when the runtime is set to run 10sec this will terminate immediately
+    # because of the exit statement in the D script.
+    consumer.run_script(SCRIPT, runtime=10)
 
 if __name__ == '__main__':
     main()
